package controller

import (
	"github.com/gin-gonic/gin"
	"strconv"
	"time"
	"trading-go/model"
	"trading-go/response"
)

// Upload
// @Tags 图片模块
// @Summary 上传图片
// @Accept multipart/form-data
// @Produce application/json
// @Param pic formData file true "图片"
// @Success 200 {object} response.Response
// @Router /pic/upload [post]
func Upload(c *gin.Context) {
	var pic model.Pic
	file, err := c.FormFile("pic")
	if err != nil {
		msg := err.Error()
		response.Fail(c.Writer, msg, 500)
		return
	}
	file.Filename = time.Now().String() + file.Filename
	path := "./pic/" + file.Filename
	err = c.SaveUploadedFile(file, path)
	if err != nil {
		msg := err.Error()
		response.Fail(c.Writer, msg, 500)
		return
	}
	url := "http://" + c.Request.Host + file.Filename
	pic.Name = file.Filename
	pic.Url = url
	err = pic.Save()
	if err != nil {
		msg := err.Error()
		response.Fail(c.Writer, msg, 500)
		return
	}
	response.Success(c.Writer, "success", model.Pic{})
}

// GetAllPic
// @Tags 图片模块
// @Summary 获取所有图片
// @Produce application/json
// @Success 200 {object} response.Response
// @Router /pic [get]
func GetAllPic(c *gin.Context) {
	var pic model.Pic
	pics, err := pic.GetAll()
	if err != nil {
		msg := err.Error()
		response.Fail(c.Writer, msg, 500)
		return
	}
	response.Success(c.Writer, "success", pics)
}

// DPic
// @Tags 图片模块
// @Summary 删除图片
// @Produce application/json
// @Param id path uint true "图片id"
// @Success 200 {object} response.Response
// @Router /pic/delete/{id} [delete]
func DPic(c *gin.Context) {
	var pic model.Pic
	ids := c.Param("id")
	id, err := strconv.Atoi(ids)
	if err != nil {
		response.Fail(c.Writer, err.Error(), 500)
		return
	}
	pic.Id = uint(id)
	err = pic.Delete()
	if err != nil {
		msg := err.Error()
		response.Fail(c.Writer, msg, 500)
		return
	}
	response.Success(c.Writer, "success", nil)
}
